summaryrefslogtreecommitdiffstats
path: root/source4/smbd/process_single.c
diff options
context:
space:
mode:
authorAndrew Tridgell <tridge@samba.org>2005-01-30 02:55:30 +0000
committerGerald (Jerry) Carter <jerry@samba.org>2007-10-10 13:09:23 -0500
commit1447b9a8c135ddc8d369be9ab970a4cccf4ecf0e (patch)
treefea0e3bc04a63cb7d3eb0dfad86e0589b12a235d /source4/smbd/process_single.c
parent597142ddd3575a50a491a89dd5ce5fb40945028f (diff)
downloadsamba-1447b9a8c135ddc8d369be9ab970a4cccf4ecf0e.tar.gz
samba-1447b9a8c135ddc8d369be9ab970a4cccf4ecf0e.tar.xz
samba-1447b9a8c135ddc8d369be9ab970a4cccf4ecf0e.zip
r5104: - added support for task based servers. These are servers that within
themselves are run as a single process, but run as a child of the main process when smbd is run in the standard model, and run as part of the main process when in the single mode. - rewrote the winbind template code to use the new task services. Also fixed the packet queueing - got rid of event_context_merge() as it is no longer needed (This used to be commit 339964a596689278d2138cff05d7d444798a3504)
Diffstat (limited to 'source4/smbd/process_single.c')
-rw-r--r--source4/smbd/process_single.c18
1 files changed, 15 insertions, 3 deletions
diff --git a/source4/smbd/process_single.c b/source4/smbd/process_single.c
index d6217d87125..7d43855f6c1 100644
--- a/source4/smbd/process_single.c
+++ b/source4/smbd/process_single.c
@@ -59,17 +59,29 @@ static void single_accept_connection(struct event_context *ev,
new_conn(ev, sock2, socket_get_fd(sock), private);
}
+/*
+ called to startup a new task
+*/
+static void single_new_task(struct event_context *ev,
+ void (*new_task)(struct event_context *, uint32_t, void *),
+ void *private)
+{
+ static uint32_t taskid = 0x10000000;
+ new_task(ev, taskid++, private);
+}
+
-/* called when a connection goes down */
-static void single_terminate_connection(struct event_context *ev, const char *reason)
+/* called when a task goes down */
+static void single_terminate(struct event_context *ev, const char *reason)
{
}
static const struct model_ops single_ops = {
.name = "single",
.model_init = single_model_init,
+ .new_task = single_new_task,
.accept_connection = single_accept_connection,
- .terminate_connection = single_terminate_connection,
+ .terminate = single_terminate,
};
/*